---
name: Add a new reference
about: Suggest a new reference to be onboarded to Helix
title: "[Reference] Please add a new reference"
labels: reference
assignees: chaplin89

---

Hi.
I'd like Helix to support a new reference:
- [URL](https://url to FASTA here):
- Build (e.g., 37, 38)

Thank you,
[Your name]
